searchData={"items":[{"type":"module","title":"UniqueWordsSigil","doc":"~u Sigil\n--------\nUnique-word strings, lists, HTML classes, checked at compile time.\n\nExamples\n--------\n```\n~u\"hello world\"      -> \"hello world\"\n~u\" hello  world \"   -> \"hello world\"  # whitespace is trimmed and \"collapsed\"\n~u\" hello  world \"l  -> [\"hello\", \"world\"]\n~u\" hello  world \"a  -> [:hello, :world]\n~u\" hello  world \"c  -> [~c\"hello\", ~c\"world\"]\n~u\" hi     hi    \"   -> (ArgumentError) Duplicate word: hi\n~u\" hi-hi  hi-hi \"w  -> \"hi-hi hi-hi\"        Warning: Duplicate word: hi-hi\n~u\" hi     hi    \"wl -> [\"hi\", \"hi\"]         Warning: Duplicate word: hi\n~u\" hi-hi  hi-hi \"aw -> [:\"hi-hi\", :\"hi-hi\"] Warning: Duplicate word: hi-hi\n~u\" hi     hi    \"cw -> [~c\"hi\", ~c\"hi\"]     Warning: Duplicate word: hi\n                                                      ~~~~~~~~~~~~~~~~~~\n```\n\n~u is ideal for HTML classes used with templating systems such as\nTemple (https://github.com/mhanberg/temple):\n```\ndiv class: ~u\"flex items-center flex\" do # (CompilerError) Duplicate word: flex\n  p class: ~u\"text-lg font-bold\n              text-gray text-lg\"  # ────── (CompilerError) Duplicate word: text-lg\n  do                  #    └───── Effortless multiline classes promote readability\n    \"Hello world\"     #          (~u automatically strips whitespace and newlines)\n  end\nend\n```\n\n~u also works well with string interpolation:\n```\na href: ~p\"/link/url\"\n  class: ~u\"flex items-center h-8 text-sm pl-8 pr-3\n    #{if(@active, do: ~u\"bg-slate\", else: ~u\"hover:bg-slate\")}\n    items-center text-blue\"      # Duplicate word: items-center\ndo\n  \"Link text\"\nend\n```\n\nCAVEAT: Being unknown during compilation, interpolations WON'T be uniqueness-checked by default.\n\n`i` modifier may be added to check uniqueness of interpolated sections at runtime:\n```\n~u\" hi hello #{\"h\" <> \"i\"}\"i -> (RuntimeError) Duplicate word: hi\n```\nInterpolation uniqueness-checking is disabled unless ***`i`*** modifier is set to\nto avoid unintended runtime overhead.\n\nWhen `Mix.env() == :prod`, interpolation uniqueness-checking will ALWAYS be disabled\neven when ***`i`*** modifier is set (this caters to the most common use-case).","ref":"UniqueWordsSigil.html"},{"type":"function","title":"UniqueWordsSigil.check_unique/2","doc":"","ref":"UniqueWordsSigil.html#check_unique/2"},{"type":"function","title":"UniqueWordsSigil.collapse_whitespace/1","doc":"","ref":"UniqueWordsSigil.html#collapse_whitespace/1"},{"type":"macro","title":"UniqueWordsSigil.invalid_modifiers_message/1","doc":"","ref":"UniqueWordsSigil.html#invalid_modifiers_message/1"},{"type":"function","title":"UniqueWordsSigil.maybe_check_unique/2","doc":"","ref":"UniqueWordsSigil.html#maybe_check_unique/2"},{"type":"macro","title":"UniqueWordsSigil.sigil_u/2","doc":"","ref":"UniqueWordsSigil.html#sigil_u/2"},{"type":"macro","title":"UniqueWordsSigil.valid_modifiers/0","doc":"","ref":"UniqueWordsSigil.html#valid_modifiers/0"},{"type":"extras","title":"Unique-Words Sigil","doc":"# Unique-Words Sigil\n\n***`~u`*** **sigil ·** unique-word strings, lists, HTML classes, checked at compile time\n\nIdeal for HTML classes used with templating systems such as [Temple](https://github.com/mhanberg/temple):\n\n```elixir\ndiv class: ~u\"flex items-center flex\" do # (CompilerError) Duplicate word: flex\n  p class: ~u\"text-lg font-bold\n              text-gray text-lg\"  # ────── (CompilerError) Duplicate word: text-lg\n  do                  #    └───── Effortless multiline classes promote readability\n    \"Hello world\"     #          (~u automatically strips whitespace and newlines)\n  end\nend\n```","ref":"readme.html"},{"type":"extras","title":"Installation - Unique-Words Sigil","doc":"Add `unique_words_sigil` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:unique_words_sigil, \"~> 0.1.0\"}\n  ]\nend\n```\nthen\n```\nmix deps.get\n```\nStart up a repl:\n```elixir\n$ iex -S mix\n\niex> import UniqueWordsSigil\n\niex> ~u\" hello  world \"\n\"hello world\"  # Whitespace trimmed, extra space & newlines ignored.\n\niex> ~u\" hello  world hello  again\"\n** (ArgumentError) Duplicate word: hello  # Duplicate words prevented ⚔️\n\niex> {~u\" hello  world \"l, ~u\" hello  world \"a, ~u\" hello  world \"c}\n{[\"hello\", \"world\"], [:hello, :world], [~c\"hello\", ~c\"world\"]}\n# String lists, atoms, charlists, oh my! (parity with ~w sigil)\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Unique-Words Sigil","doc":"```elixir\n~u\"hello world\"      -> \"hello world\"\n~u\" hello  world \"   -> \"hello world\"  # whitespace is trimmed and \"collapsed\"\n~u\" hello  world \"l  -> [\"hello\", \"world\"]\n~u\" hello  world \"a  -> [:hello, :world]\n~u\" hello  world \"c  -> [~c\"hello\", ~c\"world\"]\n~u\" hi     hi    \"   -> (ArgumentError) Duplicate word: hi\n~u\" hi-hi  hi-hi \"w  -> \"hi-hi hi-hi\"        Warning: Duplicate word: hi-hi\n~u\" hi     hi    \"wl -> [\"hi\", \"hi\"]         Warning: Duplicate word: hi\n~u\" hi-hi  hi-hi \"aw -> [:\"hi-hi\", :\"hi-hi\"] Warning: Duplicate word: hi-hi\n~u\" hi     hi    \"cw -> [~c\"hi\", ~c\"hi\"]     Warning: Duplicate word: hi\n                                                      ~~~~~~~~~~~~~~~~~~\n```\n\n***`~u`*** works well with interpolation and multi-line strings:\n\n```elixir\na href: ~p\"/link/url\"\n  class: ~u\"flex items-center h-8 text-sm pl-8 pr-3\n    #{if(@active, do: ~u\"bg-slate\", else: ~u\"hover:bg-slate\")}\n    items-center text-blue\"  # ────── Duplicate word: items-center\ndo          #  └───── Effortless multiline classes promote readability\n   \"Text\"   #        (~u automatically strips whitespace and newlines)\nend\n```\n> [!IMPORTANT]\n> By default, interpolations WON'T be uniqueness-checked (they're unknown at compile-time).\n\n***`i`*** modifier may be added to check uniqueness of interpolated sections at runtime:\n```elixir\n~u\" hi hello \\#{\"h\" <> \"i\"}\"i -> (RuntimeError) Duplicate word: hi\n```\nInterpolation uniqueness-checking is disabled unless ***`i`*** modifier is set to avoid\nunintended runtime overhead.\n\nWhen `Mix.env() == :prod`, interpolation uniqueness-checking will ALWAYS be disabled\neven when ***`i`*** modifier is set (this behavior caters to the most common use-case).\n\n# License\n\nMIT","ref":"readme.html#usage"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}